Utils Used by RevEngine3r co.

<br><br>
pip3 install -U RevUtils
<br><br>

Aria2
<br>
General purpose
<br>
IO utils
<br>
Logging utils
<br>
OS 
Some Persian Tools
<br>
Rar command line
<br>
Threading
<br>
and ...

